API
===

Utilities
=========

.. automodule:: cnxdb.utils

Initialization
==============

:mod:`cnxdb.init`
-----------------

.. automodule:: cnxdb.init

:mod:`cnxdb.manifest`
---------------------

.. automodule:: cnxdb.manifest

CRUD
====

:mod:`cnxdb.create`
-------------------

.. automodule:: cnxdb.create

:mod:`cnxdb.delete`
-------------------

.. automodule:: cnxdb.delete
   
:mod:`cnxdb.read`
-----------------

.. automodule:: cnxdb.read

:mod:`cnxdb.update`
-------------------

.. automodule:: cnxdb.update

Migrations
==========

:mod:`cnxdb.migrations`
-----------------------

.. automodule:: cnxdb.
